==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-65.js <==
dispMUA.arDispMUAAllocation["e"] =
{
  "esmtp (eudora internet mail server" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "eyepin multi campaign server" : [ "eyepin.png" ] ,
  "ensemble email services" : [ "ensemble.png" ] ,
  "eyepin campaign server" : [ "eyepin.png" ] ,
  "egroups message poster" : [ "egroups.png" ] ,
  "ebesucher mailserver" : [ "ebesucher.png" , "http://www.ebesucher.de/" ] ,
  "ebanka email robot" : [ "ebanka.png" ] ,
  "erweiterungen.de" : [ "erweiterungen_de.png" , "http://www.erweiterungen.de/" ] ,
  "endymion mailman" : [ "endymion.png" ] ,
  "ecn communicator" : [ "ecn.png" ] ,
  "exclamationsoft" : [ "exclamationsoft.png" ] ,
  "eharmony mailer" : [ "eharmony.png" ] ,
  "ezine director" : [ "ezinedirector.png" , "http://www.ezinedirector.com/" ] ,
  "ez components" : [ "ezcomponents.png" , "http://www.ezcomponents.org/" ] ,
  "everymail.net" : [ "everymail_net.png" , "http://www.everymail.net/" ] ,
  "expressomail" : [ "expressomail.png" ] ,
  "eloqua email" : [ "eloqua.png" ] ,
  "electromundo" : [ "electromundo.png" , "http://www.electromundo.com/" ] ,
  "ec-messenger" : [ "ecircle.png" , "http://www.ecircle.com/" ] ,
  "epoc e-mail" : [ "epoc.png" ] ,
  "emailgarage" : [ "emailgarage.png" ] ,
  "e-undertown" : [ "e-undertown.png" ] ,
  "e-messenger" : [ "e-messenger.png" , "http://www.e-village.nl/" ] ,
  "epoc email" : [ "epoc.png" ] ,
  "emm-xpress" : [ "emm-xpress.png" , "http://www.emm-xpress.de/" ] ,
  "eircom net" : [ "eircom_net.png" , "http://www.eircom.net/" ] ,
  "egroups-ew" : [ "yahoo.png" , "http://www.yahoo.com/" ] ,
  "ebizmailer" : [ "ebizmailer.png" ] ,
  "evolution" : [ "evolution.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "easy-mail" : [ "easy-mail.png" , "http://www.easy-mail.de/" ] ,
  "earthlink" : [ "earthlink.png" , "http://www.earthlink.net/" ] ,
  "evernote" : [ "evernote.png" , "http://www.evernote.com/" ] ,
  "esupport" : [ "esupport.png" , "http://www.kayako.com/esupport.php" ] ,
  "emailink" : [ "emailink.png" , "http://www.innomatix.com/" ] ,
  "email.bg" : [ "email_bg.png" , "http://www.email.bg/" ] ,
  "element5" : [ "element5.png" ] ,
  "eibport_" : [ "eibport.png" ] ,
  "ebilling" : [ "ebilling.png" ] ,
  "explido" : [ "explido.png" , "http://www.explido-software.de/permission_marketing.0.html" ] ,
  "epirent" : [ "epirent.png" , "http://www.epirent.de/" ] ,
  "energit" : [ "energit.png" , "http://www.energit.it/" ] ,
  "emumail" : [ "emumail.png" ] ,
  "email " : [ "email.png" , "http://www.cleancode.org/projects/email" ] ,
  "eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "emplex" : [ "emplex.png" ] ,
  "emill/" : [ "emill.png" ] ,
  "elaine" : [ "elaine.png" ] ,
  "edmail" : [ "edmail.png" ] ,
  "empal" : [ "empas.png" ] ,
  "elion" : [ "elion_hot.png" , "http://www.hot.ee/" ] ,
  "edmax" : [ "edmax.png" ] ,
  "exmh" : [ "exmh.png" ] ,
  "exim" : [ "exim.png" , "http://www.exim.org/" ] ,
  "emcl" : [ "t-mobile.png" , "http://www.t-mobile.de/email" ] ,
  "ems" : [ "ems.png" , "http://www.emailing-solution.com/" ] ,
  "elm" : [ "elm.png" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-65.js <==
dispMUA.arDispMUAAllocation["e"] =
{
  "esmtp (eudora internet mail server" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "eyepin multi campaign server" : [ "eyepin.png" ] ,
  "ensemble email services" : [ "ensemble.png" ] ,
  "eyepin campaign server" : [ "eyepin.png" ] ,
  "egroups message poster" : [ "egroups.png" ] ,
  "ebesucher mailserver" : [ "ebesucher.png" , "http://www.ebesucher.de/" ] ,
  "ebanka email robot" : [ "ebanka.png" ] ,
  "erweiterungen.de" : [ "erweiterungen_de.png" , "http://www.erweiterungen.de/" ] ,
  "endymion mailman" : [ "endymion.png" ] ,
  "ecn communicator" : [ "ecn.png" ] ,
  "exclamationsoft" : [ "exclamationsoft.png" ] ,
  "eharmony mailer" : [ "eharmony.png" ] ,
  "ezine director" : [ "ezinedirector.png" , "http://www.ezinedirector.com/" ] ,
  "ez components" : [ "ezcomponents.png" , "http://www.ezcomponents.org/" ] ,
  "everymail.net" : [ "everymail_net.png" , "http://www.everymail.net/" ] ,
  "expressomail" : [ "expressomail.png" ] ,
  "evolution 2." : [ "evolution2.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "eloqua email" : [ "eloqua.png" ] ,
  "electromundo" : [ "electromundo.png" , "http://www.electromundo.com/" ] ,
  "ec-messenger" : [ "ecircle.png" , "http://www.ecircle.com/" ] ,
  "epoc e-mail" : [ "epoc.png" ] ,
  "emailgarage" : [ "emailgarage.png" ] ,
  "easycall.pl" : [ "easycall_pl.png" , "http://www.easycall.pl/" ] ,
  "e-undertown" : [ "e-undertown.png" ] ,
  "e-messenger" : [ "e-messenger.png" , "http://www.e-village.nl/" ] ,
  "epoc email" : [ "epoc.png" ] ,
  "emm-xpress" : [ "emm-xpress.png" , "http://www.emm-xpress.de/" ] ,
  "eircom net" : [ "eircom_net.png" , "http://www.eircom.net/" ] ,
  "egroups-ew" : [ "yahoo.png" , "http://www.yahoo.com/" ] ,
  "ebizmailer" : [ "ebizmailer.png" ] ,
  "evolution" : [ "evolution.png" , "http://www.gnome.org/projects/evolution/" ] ,
  "easy-mail" : [ "easy-mail.png" , "http://www.easy-mail.de/" ] ,
  "earthlink" : [ "earthlink.png" , "http://www.earthlink.net/" ] ,
  "evernote" : [ "evernote.png" , "http://www.evernote.com/" ] ,
  "esupport" : [ "esupport.png" , "http://www.kayako.com/esupport.php" ] ,
  "emailink" : [ "emailink.png" , "http://www.innomatix.com/" ] ,
  "email.bg" : [ "email_bg.png" , "http://www.email.bg/" ] ,
  "element5" : [ "element5.png" ] ,
  "eibport_" : [ "eibport.png" ] ,
  "ebilling" : [ "ebilling.png" ] ,
  "e-mailer" : [ "e-mailer.png" , "http://www.assesso.com.br/Zope.pcgi/index_html?Secao=34" ] ,
  "explido" : [ "explido.png" , "http://www.explido-software.de/permission_marketing.0.html" ] ,
  "epirent" : [ "epirent.png" , "http://www.epirent.de/" ] ,
  "energit" : [ "energit.png" , "http://www.energit.it/" ] ,
  "emumail" : [ "emumail.png" ] ,
  "email " : [ "cleancode-email.png" , "http://www.cleancode.org/projects/email" ] ,
  "eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "epylog" : [ "epylog.png" , "http://linux.duke.edu/projects/epylog/" ] ,
  "emplex" : [ "emplex.png" ] ,
  "emill/" : [ "emill.png" ] ,
  "elaine" : [ "elaine.png" ] ,
  "edmail" : [ "edmail.png" ] ,
  "empal" : [ "empas.png" ] ,
  "elion" : [ "elion_hot.png" , "http://www.hot.ee/" ] ,
  "edmax" : [ "edmax.png" ] ,
  "exmh" : [ "exmh.png" ] ,
  "exim" : [ "exim.png" , "http://www.exim.org/" ] ,
  "emcl" : [ "t-mobile.png" , "http://www.t-mobile.de/email" ] ,
  "ems" : [ "ems.png" , "http://www.emailing-solution.com/" ] ,
  "elm" : [ "elm.png" ] ,
}
